c              eventLoop
      subroutine ceventLoop
      implicit none
#include  "Zmanagerp.h"
#include  "Zmanager.h"
#include  "Ztrack.h"
#include  "Zprimary.h"
#include  "Zprimaryv.h"
#include  "Zcondc.h"


      record /track/ incident
      integer jold
      integer fin, jeof

      do while (EventNo .lt. abs( DestEventNo(1)) .and. 
     *      EventsInTheRun .lt. abs( DestEventNo(2)))
         EventsInTheRun = EventsInTheRun + 1
         EventNo = EventNo + 1
c             switch to the random number generator 1
         call rndsw(jold, 1)
         if(Job .eq. 'flesh') then
c                get random seed at skelton making
            call creadSeed(SeedSave, EventNo, jeof)
            if( jeof .ne. 0 ) goto 10
c                reset the seed.
            call rnd1r(SeedSave)
         else
c              save the initial seed of random number
            call rnd1s(SeedSave)
            if(Job .eq. ' ' .and. SeedFile .ne. ' ') then
               call cwriteSeed
            endif
         endif            
         call cmkIncident(incident, fin)
         if(fin .ne. 0) goto 10  ! all including cuoffed end
         call ciniTracking    ! init for tracking each event
         call cinitStack
         call cpush(incident)

         call chookBgEvent    ! user hook for each event beginning

         call ctrackingAll
         call cfinTracking    ! enf of tracking of each event
         call chookEnEvent    ! user hook for each event  end

      enddo
 10   continue
      end
c     ****************************************************
c          inquire the initial random seed
      subroutine  cqIniRn(ir)
      implicit none
#include  "Zmanager.h"
      integer ir(2)
      
      ir(1) = SeedSave(1)
      ir(2) = SeedSave(2)
      end
c     ****************************************************
c          write iformation for initial random number for flesh
c        at skelton making time
      subroutine cwriteSeed
      implicit none
#include "Zmanagerp.h"      
#include "Zmanager.h"      

      write(SeedFileDev, *)  SeedSave, EventNo
      end
c     ****************************************************
c          read iformation for initial random number at flesh time
      subroutine creadSeed(ir, no, jeof)
      implicit none
#include "Zmanagerp.h"      

      integer ir(2), no, jeof

      integer nn
      integer count
      data count/0/
      save count

      jeof = 0
      do while(.true.)
         read(SeedFileDev, *, end=100) ir, nn
         if(nn .ge. EventNo) goto 200  ! skip already processed ones
      enddo

 100  continue
      jeof =1
      if(count .eq. 0) then
         count = count + 1
         call cerrorMsg(
     *        'No more events to be fleshed',1)
         call cerrorMsg(
     *        'EOF of the seed file reached', 1)
      else
         call cerrorMsg(
     *  '2nd time to read EOF of the  seed file',0)
      endif
 200  continue
      no = nn
      end
c      inquire the event number
      subroutine cqEventNo(num, cumnum)
      implicit none
#include "Zmanagerp.h"      
      integer num   ! output. number of events in the current run
      integer cumnum ! output. cummulative number of events so far.
c     may be used  after the initialization of an event, then
c     this gives the number for that event.
c      

      num = EventsInTheRun
      cumnum = EventNo
      end
